# remirepo/fedora spec file for php-composer-pcre3
#
# Copyright (c) 2021-2022 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%bcond_without       tests

%global gh_commit    e300eb6c535192decd27a85bc72a9290f0d6b3bd
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
#global gh_date      20150717
%global gh_owner     composer
%global gh_project   pcre
%global ns_vendor    Composer
%global ns_project   Pcre
%global php_home     %{_datadir}/php
%global major        3

Name:           php-%{gh_owner}-%{gh_project}%{major}
Version:        3.0.0
Release:        1%{?gh_date:.%{gh_date}git%{gh_short}}%{?dist}
Summary:        PCRE wrapping library version %{major}

License:        MIT
URL:            https://github.com/%{gh_owner}/%{gh_project}
# git snapshot to get upstream test suite
Source0:        %{name}-%{version}-%{gh_short}.tgz
Source1:        makesrc.sh

BuildArch:      noarch
%if %{with tests}
# For tests
BuildRequires:  php(language) >= 7.4
BuildRequires:  php-pcre
BuildRequires:  php-spl
# From composer.json,     "require-dev": {
#        "symfony/phpunit-bridge": "^5",
#        "phpstan/phpstan": "^1.3",
#        "phpstan/phpstan-strict-rules": "^1.1"
%global         phpunit /usr/bin/phpunit9
BuildRequires:  %{phpunit}
# Autoloader
BuildRequires:  php-fedora-autoloader-devel
%endif

# From composer.json, "require": {
#       "php": "^7.4 || ^8.0"
Requires:       php(language) >= 7.4
# From phpcompatinfo report for version 1.0.0
Requires:       php-pcre
Requires:       php-spl
# Autoloader
Requires:       php-composer(fedora/autoloader)

Provides:       php-composer(%{gh_owner}/%{gh_project}) = %{version}


%description
PCRE wrapping library that offers type-safe preg_* replacements.

This library gives you a way to ensure preg_* functions do not fail silently,
returning unexpected nulls that may not be handled.

It also makes it easier ot work with static analysis tools like PHPStan or
Psalm as it simplifies and reduces the possible return values from all the
preg_* functions which are quite packed with edge cases.

Autoloader: %{_datadir}/php/%{ns_vendor}/%{ns_project}%{major}/autoload.php


%prep
%setup -q -n %{gh_project}-%{gh_commit}


%build
: Generate classmap autoloader
phpab --template fedora --output src/autoload.php src


%install
: Library
mkdir -p   %{buildroot}%{php_home}/%{ns_vendor}/
cp -pr src %{buildroot}%{php_home}/%{ns_vendor}/%{ns_project}%{major}


%check
%if %{with tests}
mkdir vendor
cat << 'EOF' | tee vendor/autoload.php
<?php
require_once "%{buildroot}%{php_home}/%{ns_vendor}/%{ns_project}%{major}/autoload.php";
\Fedora\Autoloader\Autoload::addPsr4('%{ns_vendor}\\%{ns_project}', dirname(__DIR__).'/tests');
EOF

ret=0
for cmd in php php74 php80 php81; do
  if which $cmd; then
    $cmd %{phpunit} \
      --verbose || ret=1
  fi
done

exit $ret
%else
: Test suite disabled
%endif


%files
# remirepo:1
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc composer.json
%doc *.md
%dir %{php_home}/%{ns_vendor}
     %{php_home}/%{ns_vendor}/%{ns_project}%{major}


%changelog
* Thu Mar 31 2022 Remi Collet <remi@remirepo.net> - 3.0.0-1
- update to 3.0.0
- rename to php-composer-pcre3
- install in /usr/share/php/Composer/Pcre3
- raise dependency on PHP 7.4

* Sat Jan 22 2022 Remi Collet <remi@remirepo.net> - 1.0.1-1
- update to 1.0.1

* Wed Dec  8 2021 Remi Collet <remi@remirepo.net> - 1.0.0-1
- initial package, version 1.0.0
